      subroutine gridcheck(error)
***********************************************************************
*                                                                     * 
*             TRAJECTORY MODEL SUBROUTINE GRIDCHECK (MM5 VERSION)     *
*                                                                     *
***********************************************************************
*                                                                     * 
*             AUTHOR:      G. WOTAWA                                  *
*             DATE:        1997-08-06                                 *
*                                                                     * 
*             Update:      1998-12, global fields allowed, A. Stohl   * 
*                                                                     * 
***********************************************************************
*                                                                     *
* DESCRIPTION:                                                        *
*                                                                     *
* THIS SUBROUTINE DETERMINES THE GRID SPECIFICATIONS (LOWER LEFT      *
* LONGITUDE, LOWER LEFT LATITUDE, NUMBER OF GRID POINTS, GRID DIST-   *
* ANCE AND VERTICAL DISCRETIZATION OF THE ECMWF MODEL) FROM THE       *
* GRIB HEADER OF THE FIRST INPUT FILE. THE CONSISTANCY (NO CHANGES    *
* WITHIN ONE FLEXTRA RUN) IS CHECKED IN THE ROUTINE "READWIND" AT ANY *
* CALL.                                                               *
*                                                                     *
* OUTPUT       error .true.   - can not read grid specifications      *
*              error .false.  - normal                                *
*                                                                     * 
* XLON0                geographical longitude of lower left gridpoint *
* XLAT0                geographical latitude of lower left gridpoint  *
* NX                   number of grid points x-direction              *
* NY                   number of grid points y-direction              *
* DX                   grid distance x-direction                      *
* DY                   grid distance y-direction                      *
* NUVZ                 number of grid points for horizontal wind      *
*                      components in z direction                      *
* NWZ                  number of grid points for vertical wind        *
* SIGMAHALF(1)-        heights of gridpoints where u and v are        *
* SIGMAHALF(NUVZ)      given                                          *
* SIGMAFULL(1)-        heights of gridpoints where w is given         *
* SIGMAFULL(NWZ)                                                      *
*                                                                     *
***********************************************************************
*
      include 'includepar'
      include 'includecom'

      integer i,ifn,ifield,j,k,iumax,iwmax
      integer nxmother,nymother
      real dxmother,dymother,xpos1,ypos1
      logical error

* VARIABLES AND ARRAYS NEEDED FOR GRIB DECODING

      integer isec0(2),isec1(56),isec2(512),isec3(2),isec4(64)
      integer inbuff(jpack),ilen,ierr,iword,lunit
      real zsec2(128),zsec3(2),zsec4(jpunp)
      character*1 yoper,opt
      data yoper/'D'/

      error=.false.
      iumax=0
      iwmax=0
*
      if(ideltas.gt.0) then
        ifn=1
      else
        ifn=numbwf
      endif
*
* OPENING OF DATA FILE (GRIB CODE)
*
5     call pbopen(lunit,path(3)(1:len(3))//wfname(ifn),'r',ierr)
      if(ierr.lt.0) goto 999

      ifield=0   
10    ifield=ifield+1
*
* GET NEXT FIELDS
*
      call pbgrib(lunit,inbuff,jpack,ilen,ierr)
      if(ierr.eq.-1) goto 30    ! EOF DETECTED
      if(ierr.lt.-1) goto 999   ! ERROR DETECTED
 
      ierr=1
      call gribex(isec0,isec1,isec2,zsec2,isec3,zsec3,isec4,
     &            zsec4,jpunp,inbuff,jpack,iword,yoper,ierr)
      if (ierr.ne.0) goto 999   ! ERROR DETECTED

      if(ifield.eq.1) then

* READ IN GRID SPECIFICATIONS

        open(unitwind,file=path(3)(1:len(3))//'GRID.TXT',
     &    status='old',err=996)

        read(unitwind,*) iproj
        if(iproj.ne.1) goto 995
        read(unitwind,*) nx
        read(unitwind,*) ny
        read(unitwind,*) nsigmahalf
        read(unitwind,*) dx
        dx=dx*1000.    ! Reference unit = m
        dy=dx  ! Only dx=dy possible in MM5...
        read(unitwind,*) nxmother
        read(unitwind,*) nymother
        read(unitwind,*) dxmother
        dxmother=dxmother*1000.
        dymother=dxmother
        read(unitwind,*) xpos1
        read(unitwind,*) ypos1
        read(unitwind,*) xloncenter
        read(unitwind,*) ylatcenter
        read(unitwind,*)
        read(unitwind,*)
        read(unitwind,*)
        read(unitwind,*)
        read(unitwind,*) truelat
        read(unitwind,*) conef
        read(unitwind,*) p00
        read(unitwind,*) ptop
        read(unitwind,*) ts0
        read(unitwind,*) ta
        do 15 k=1,nsigmahalf
15        read(unitwind,*) sigmahalf(nsigmahalf-k+1)
        sigmafull(1)=1.0
        do 16 k=1,nsigmahalf
16        sigmafull(k+1)=2.*sigmahalf(k)-sigmafull(k)
        sigmafull(nsigmahalf+1)=0.0
        write(*,*)
        write(*,'(a)') 'LEV    SIGMA   HALFSIGMA'
        write(*,*)
        do 17 k=1,nsigmahalf
17        write(*,'(i3,2f9.4)') k,sigmafull(k),sigmahalf(k)
        write(*,'(i3,f9.4)') nsigmahalf+1,sigmafull(nsigmahalf+1)
        write(*,*)

        xlon0=-0.5*float(nxmother-1)*dxmother+(xpos1-1.0)*dxmother
        ylat0=-0.5*float(nymother-1)*dymother+(ypos1-1.0)*dymother

        xglobal=.false.
        sglobal=.false.
        switchsouthg=999999.
        nglobal=.false.
        switchnorthg=999999.
      endif
      close(unitwind)
     
      k=isec1(8)
      if(isec1(6).eq.131) iumax=max(iumax,nsigmahalf-k+1)
      if(isec1(6).eq.135) iwmax=max(iwmax,nsigmahalf-k+2) 

      if(isec1(6).eq.129) then
        do 20 j=0,ny-1
          do 21 i=0,nx-1
21          oro(i,j)=zsec4(nx*(ny-j-1)+i+1)
20        continue
      endif

      goto 10                      !! READ NEXT LEVEL OR PARAMETER
*
* CLOSING OF INPUT DATA FILE
*
30    call pbclose(lunit,ierr)     !! FINNISHED READING / CLOSING GRIB FILE

      nuvz=iumax
      nwz =iwmax

      if (nx.gt.nxmax) then                         
      write(*,*) 'FLEXTRA error: Too many grid points in x direction.'
      write(*,*) 'Reduce resolution of wind fields (file GRIDSPEC).'
      error=.true.
      return
      endif

      if (ny.gt.nymax) then                         
      write(*,*) 'FLEXTRA error: Too many grid points in y direction.'
      write(*,*) 'Reduce resolution of wind fields (file GRIDSPEC).'
      error=.true.
      return
      endif

      if (nuvz.gt.nuvzmax) then                         
      write(*,*) 'FLEXTRA error: Too many u,v grid points in z '//
     +'direction.'
      write(*,*) 'Reduce resolution of wind fields (file GRIDSPEC).'
      error=.true.
      return
      endif

      if (nwz.gt.nwzmax) then                         
      write(*,*) 'FLEXTRA error: Too many w grid points in z '//
     +'direction.'
      write(*,*) 'Reduce resolution of wind fields (file GRIDSPEC).'
      error=.true.
      return
      endif

C Output of grid info
*********************

      write(*,*)
      write(*,*)
      write(*,'(a,2i7)') '# of vertical levels: ',nuvz,nwz
      write(*,*)
      write(*,'(a)') 'Mother domain:'
      write(*,'(a,f10.1,a1,f10.1,a,f10.1)') '  Longitude range: ',
     +xlon0,' to ',xlon0+(nx-1)*dx,'   Grid distance: ',dx
      write(*,'(a,f10.1,a1,f10.1,a,f10.1)') '  Latitude range:  ',
     +ylat0,' to ',ylat0+(ny-1)*dy,'   Grid distance: ',dy
      write(*,*)

C If vertical coordinates decrease with increasing altitude, multiply by -1.
C This means that also the vertical velocities have to be multiplied by -1.
****************************************************************************

      if (sigmahalf(1).lt.sigmahalf(nuvz)) then
        zdirect=1.
      else
        zdirect=-1.
        do 55 i=1,nuvz
55        sigmahalf(i)=zdirect*sigmahalf(i)
        do 65 i=1,nwz
65        sigmafull(i)=zdirect*sigmafull(i)
      endif

C Compute minimum and maximum height of modelling domain
********************************************************

      heightmin=max(sigmahalf(1),sigmafull(1))
      heightmax=min(sigmahalf(nuvz),sigmafull(nwz))

      return

995   write(*,'(a)') '  FLEXTRA MODEL ERROR!                  '
      write(*,'(a)') '  AT PRESENT, ONLY LAMBERT CONFORMAL     '
      write(*,'(a)') '  PROJECTION IS SUPPORTED...             '
      stop

996   write(*,'(a)') '  FLEXTRA MODEL ERROR! FILE "GRID.TXT"  '
      write(*,'(a)') '  CANNOT BE OPENED IN THE DIRECTORY      '
      write(*,'(a)') '  '//path(3)(1:len(3))
      stop

999   write(*,*)  
      write(*,*) ' ###########################################'//
     &           '###### '
      write(*,*) '       TRAJECTORY MODEL SUBROUTINE GRIDCHECK:'
      write(*,*) ' CAN NOT OPEN INPUT DATA FILE '//wfname(ifn)
      write(*,*) ' ###########################################'//
     &           '###### '
      write(*,*)
      write(*,'(a)') '!!! PLEASE INSERT A NEW CD-ROM AND   !!!'
      write(*,'(a)') '!!! PRESS ANY KEY TO CONTINUE...     !!!'
      write(*,'(a)') '!!! ...OR TERMINATE FLEXTRA PRESSING !!!'
      write(*,'(a)') '!!! THE "X" KEY...                   !!!'
      write(*,*)
      read(*,'(a)') opt
      if(opt.eq.'X') then
        error=.true.
      else
        goto 5
      endif

      return
      end
