      subroutine lamphitoxy(lam,phi,lam0,phi0,phitrue1,conef,
     &  x,y)

* THIS ROUTINE CALCULATES THE COORDINATES ON THE PROJECTION PLANE
* FROM THE COORDINATES ON EARTH (LAMBDA/PHI) 
*
*                ********************************
*                * LAMBERT CONFORMAL PROJECTION *
*                ********************************
*
* INPUT:
*
* lam          latitude
* phi          longitude
* lam0         Projection center longitude
* phi0         Projection center latitude
* phitrue1     True latitude 1
* conef        Cone factor
*
* OUTPUT:
*
* x            x position on projection plane (km relative to lam0/phi0)
* y            y position on projection plane (km relative to lam0/phi0)
*
      implicit none

      real x,y,lam0,phi0,phitrue1,conef,lam,phi

      double precision radb,cpidb
      parameter(radb=6370.0d+3)   ! Earth radius
      double precision xdb,ydb,lam0db,phi0db
      double precision phitrue1db,conefdb,lamdb,phidb
      double precision cc1db,cc2db,psi0db,psi1db,help1db,rrdb
      double precision psidb

* CONVERT TO DOUBLE PRECISION
   
      lamdb=dble(lam)
      phidb=dble(phi)
      lam0db=dble(lam0)
      phi0db=dble(phi0)
      phitrue1db=dble(phitrue1)
      conefdb=dble(conef)

      cpidb=4.0*datan(1.0d+0)/180.0d+0   ! Conversion factor to radian

* PERFORM COMPUTATIONS

      psidb=dble(0.5)*cpidb*(dble(90.0)-phidb)
      psi0db=dble(0.5)*cpidb*(dble(90.0)-phi0)
      psi1db=dble(0.5)*cpidb*phitrue1db

      rrdb=(radb/conefdb) * dsin (phitrue1db*cpidb) *
     & ((dtan(psidb)/dtan(psi1db))**conefdb)
      cc2db=(radb/conefdb) * dsin (phitrue1db*cpidb) *
     & ((dtan(psi0db)/dtan(psi1db))**conefdb)
      cc1db=-lam0db-dble(90.0)/conefdb

      help1db=conefdb*(lamdb+cc1db)
    
      xdb=rrdb*dcosd(help1db)
      ydb=rrdb*dsind(help1db)+cc2db

* CONVERT RESULT BACK TO SINGLE PRECISION

      x=sngl(xdb)
      y=sngl(ydb)

      return
      end
