      subroutine readwind(indj,n)
***********************************************************************
*                                                                     * 
*             TRAJECTORY MODEL SUBROUTINE READWIND                    *
*                                                                     *
***********************************************************************
*                                                                     * 
*             AUTHOR:      G. WOTAWA                                  *
*             DATE:        1997-08-05                                 *
*             LAST UPDATE: ----------                                 *
*             Update:      1998-07-29, global fields allowed          *
*             A. Stohl, G. Wotawa                                     * 
*                                                                     * 
***********************************************************************
*                                                                     *
* DESCRIPTION:                                                        *
*                                                                     *
* READING OF ECMWF METEOROLOGICAL FIELDS FROM INPUT DATA FILES. THE   *
* INPUT DATA FILES ARE EXPECTED TO BE AVAILABLE IN GRIB CODE          *
*                                                                     *
* INPUT:                                                              *
* indj               indicates number of the wind field to be read in *
* n                  temporal index for meteorological fields (1 to 3)*
*                                                                     *
* IMPORTANT VARIABLES FROM COMMON BLOCK:                              *
*                                                                     *
* wfname             File name of data to be read in                  *
* nx,ny,nuvz,nwz     expected field dimensions                        *
* nsigmahalf         number of vertical levels ecmwf model            *
* uu,vv,ww           wind fields                                      *
* tt,qv              temperature and specific humidity                *
* ps                 surface pressure                                 *
*                                                                     *
***********************************************************************
*
      include 'includepar'
      include 'includecom'
      integer indj,i,j,k,n,levdiff1,levdiff2,ifield,iumax,iwmax

* VARIABLES AND ARRAYS NEEDED FOR GRIB DECODING

      integer isec0(2),isec1(56),isec2(512),isec3(2),isec4(64)
      integer inbuff(jpack),ilen,ierr,lunit,iword
      real zsec2(128),zsec3(2),zsec4(jpunp)

      character*1 yoper,opt
      logical error

      data yoper/'D'/

      levdiff1=nsigmahalf-nuvz+1
      levdiff2=nsigmahalf-nwz+1
      iumax=0
      iwmax=0
*
* OPENING OF DATA FILE (GRIB CODE)
*
5     call pbopen(lunit,path(3)(1:len(3))//wfname(indj),'r',ierr)
      if(ierr.lt.0) goto 999

      ifield=0
10    ifield=ifield+1
*
* GET NEXT FIELDS
*
      call pbgrib(lunit,inbuff,jpack,ilen,ierr)
      if(ierr.eq.-1) goto 50    ! EOF DETECTED
      if(ierr.lt.-1) goto 888   ! ERROR DETECTED

      ierr=1
      call gribex(isec0,isec1,isec2,zsec2,isec3,zsec3,isec4,
     &            zsec4,jpunp,inbuff,jpack,iword,yoper,ierr)
      if (ierr.ne.0) goto 888   ! ERROR DETECTED

      if(ifield.eq.1) then

* CHECK GRID SPECIFICATIONS

        if(isec2(2).ne.nx) stop 'READWIND: NX NOT CONSISTENT'
        if(isec2(3).ne.ny) stop 'READWIND: NY NOT CONSISTENT'
        if(isec2(12).ne.nsigmahalf)
     &    stop 'READWIND: VERTICAL DISCRETIZATION NOT CONSISTENT'
      endif

      do 20 j=0,ny-1
        do 20 i=0,nx-1
          k=isec1(8)
          if(isec1(6).eq.130) tt(i,j,nsigmahalf-k+1,n)=    !! TEMPERATURE
     &                        zsec4(nx*(ny-j-1)+i+1)
          if(isec1(6).eq.131) uu(i,j,nsigmahalf-k+1,n)=    !! U VELOCITY
     &                        zsec4(nx*(ny-j-1)+i+1)
          if(isec1(6).eq.132) vv(i,j,nsigmahalf-k+1,n)=    !! V VELOCITY
     &                        zsec4(nx*(ny-j-1)+i+1)
          if(isec1(6).eq.134) ps(i,j,1,n)=              !! SURF. PRESS.
     &                        zsec4(nx*(ny-j-1)+i+1)
          if(isec1(6).eq.135) ww(i,j,nsigmahalf-k+1,n)=    !! W VELOCITY
     &                        zsec4(nx*(ny-j-1)+i+1)
          if(isec1(6).eq.129) oro(i,j)=                 !! ECMWF OROGRAPHY
     &                        zsec4(nx*(ny-j-1)+i+1)
          if(isec1(6).eq.131) iumax=max(iumax,nsigmahalf-k+1)
          if(isec1(6).eq.135) iwmax=max(iwmax,nsigmahalf-k+2)
20        continue

      goto 10                      !! READ NEXT LEVEL OR PARAMETER
*
* CLOSING OF INPUT DATA FILE
*
50    call pbclose(lunit,ierr)     !! FINISHED READING / CLOSING GRIB FILE


      if(iumax.ne.nuvz) stop 'READWIND: NUVZ NOT CONSISTENT'
      if(iwmax.ne.nwz)  stop 'READWIND: NWZ NOT CONSISTENT'

      return    
888   write(*,*) ' #### TRAJECTORY MODEL ERROR! WINDFIELD       #### ' 
      write(*,*) ' #### ',wfname(indj),'                    #### '
      write(*,*) ' #### IS NOT GRIB FORMAT !!!                  #### '
      stop 'Execution terminated'

999   write(*,*) ' #### TRAJECTORY MODEL ERROR! WINDFIELD       #### ' 
      write(*,*) ' #### ',wfname(indj),'                    #### '
      write(*,*) ' #### CANNOT BE OPENED !!!                    #### '
      write(*,*)
      write(*,'(a)') '!!! PLEASE INSERT A NEW CD-ROM AND   !!!'
      write(*,'(a)') '!!! PRESS ANY KEY TO CONTINUE...     !!!'
      write(*,'(a)') '!!! ...OR TERMINATE FLEXTRA PRESSING !!!'
      write(*,'(a)') '!!! THE "X" KEY...                   !!!'
      write(*,'(a)') '!!! PLEASE CHECK CD-ROM LABEL AND    !!!'
      write(*,'(a)') '!!! CORRECT FILE "PATHNAMES"...      !!!'
      write(*,*)
      read(*,'(a)') opt
      if(opt.eq.'X') then
        stop 'Execution terminated'
      else
        call readpaths(error)
        if(error)
     &    stop 'Error reading "pathnames" --> execution terminated'
        goto 5
      endif

      end
