      real function sigmamm5(psurf,pconst)
******************************************************************************
*                                                                            *
*                             MM5 VERSION                                    *
*                                                                            *
*     This routine computes vertical coordinate sigma for a given pressure p.*
*                                                                            *
*     Author: G. WOTAWA                                                      *
*                                                                            *
******************************************************************************
* Variables:                                                                 *
* sigmamm5              value of sigma for given pressure                    *
* fract                 help variable for linear interpolation               *
* plevel1 [Pa]          pressure of level below wanted pressure              *
* plevel2 [Pa]          pressure of level above wanted pressure              *
* pconst [Pa]           pressure level of isobaric trajectory                *
* psurf [Pa]            surface level pressure                               *
* sigmafull(nwzmax)     height of MM5 full sigma layers                      *
******************************************************************************

      include 'includepar'
      include 'includecom'

      integer i
      real plevel1,plevel2,fract,psurf,pconst
      
      plevel1=abs(sigmafull(1))*(psurf-ptop)+ptop
      if (plevel1.le.pconst) then  ! pressure higher than surface pressure
        sigmamm5=sigmafull(1)
      else                         ! normal case -> linear interpolation
        do 10 i=2,nwz              ! look, between which layers we are
          plevel2=abs(sigmafull(i))*(psurf-ptop)+ptop
          if (plevel2.lt.pconst) then
            fract=(pconst-plevel2)/(plevel1-plevel2)
            sigmamm5=sigmafull(i)*(1.-fract)+sigmafull(i-1)*fract
            goto 100
          endif
10        plevel1=plevel2
        sigmamm5=sigmafull(nwz)       ! pressure lower than highest model layer
      endif

100   continue


      if (sigmamm5.gt.heightmax) sigmamm5=heightmax
      if (sigmamm5.lt.heightmin) sigmamm5=heightmin

      return
      end
