      subroutine sigmatrafo(xt,yt,zt,itime1,itime2,itime,indexf,ngrid,
     +psint)
***********************************************************************
*                                                                     *
*                           MM5 VERSION                               *
*             TRAJECTORY MODEL SUBROUTINE SIGMATRAFO                  *
*                                                                     *
***********************************************************************
*                                                                     *
*             AUTHOR:      G. WOTAWA                                  *
*             DATE:        1994-04-06                                 *
*             LAST UPDATE: ----------                                 *
*                                                                     *
***********************************************************************
*                                                                     *
* DESCRIPTION: This subroutine transforms the vertical coordinate     *
*              from z-coordinate system [m] to sigma-coordinate       *
*              system [MM5]                                           *
*              Remark: Just call after initialization of a new        *
*              trajectory (first call of getwind)                     *
*                                                                     *
***********************************************************************
*                                                                     *
* INPUT:                                                              *
*                                                                     *
* xt                         x-coordinate of point [grid units]       *
* yt                         y-coordinate of point [grid units]       *
* zt                         z-coordinate of point [m]                *
* itime1                     time [s] of first windfield              *
* itime2                     time [s] of second windfield             *
* itime                      time [s] of calculation                  *
* indexf                     time index of field xx                   *
* psint                      surface pressure at point (xt,yt) [Pa]   *
*                                                                     *
***********************************************************************
*                                                                     *
* OUTPUT:                                                             *
*                                                                     *
* zt                         z-coordinate of point [eta ECMWF]        *
*                                                                     *
***********************************************************************
*
      include 'includepar'
      include 'includecom'

      integer itime1,itime2,itime,indexf,k,ngrid
      real xt,yt,zt,psint,fract,geopot1,sigmatoh
      real zzlev(nwzmax)

      geopot1=sigmatoh(abs(sigmafull(1)),psint,ptop,p00,ts0,ta)
*
* calculate geometric height on model levels
*
      zzlev(1)=0.0

      if (zt.lt.zzlev(1)) then
        write(*,*) ' TRAJECTORY MODEL: NOTICE - STARTING POINT OUT'//
     &             ' OF MODEL DOMAIN'
        write(*,*) ' (VERTICAL) HAS BEEN DETECTED --> IT IS SET TO'//
     &             ' THE BOTTOM OF THE MODEL ...'
        zt=sigmahalf(1)
        return
      endif

      do 15 k=2,nwz
        zzlev(k)=sigmatoh(abs(sigmafull(k)),psint,ptop,p00,ts0,ta)-
     +   geopot1
        if(zt.lt.zzlev(k)) goto 20
15    continue
      write(*,*) ' TRAJECTORY MODEL: NOTICE - STARTING POINT OUT'//
     &           ' OF MODEL DOMAIN'
      write(*,*) ' (VERTICAL) HAS BEEN DETECTED --> IT IS SET TO'//
     &           ' THE TOP OF THE MODEL ...'
      zt=sigmahalf(nuvz)
      return

20    fract=(zt-zzlev(k-1))/(zzlev(k)-zzlev(k-1))
      zt=sigmafull(k-1)*(1.-fract)+sigmafull(k)*fract
      if(zt.lt.sigmahalf(1)) zt=sigmahalf(1)
      if(zt.gt.sigmahalf(nuvz)) zt=sigmahalf(nuvz)
      return
      end
