      subroutine wtransform(wint,psint,zt,indwz,dzdt)
***********************************************************************
*                                                                     *
*                        MM5 VERSION                                  *
*                                                                     *
*             TRAJECTORY MODEL SUBROUTINE WTRANSFORM                  *
*                                                                     *
***********************************************************************
*                                                                     *
*             AUTHOR:      G. WOTAWA                                  *
*             DATE:        1994-02-14                                 *
*             LAST UPDATE: 1994-05-04                                 *
*             MM5 Version: 1999-11-19                                 *
*                                                                     *
***********************************************************************
*                                                                     *
* DESCRIPTION: This subroutine transforms the interpolated vertical   *
* wind <wint> from m/s to sigma coordinate                            *
*                                                                     *
***********************************************************************
*                                                                     *
* INPUT:                                                              *
*                                                                     *
* wint    interpolated vertical wind component [Pa/s]                 *
* psint   interpolated surface pressure        [Pa]                   *
* zt      vertical position of coordinate      [eta]                  *
* indwz   index which shows between which model layers trajectory is  *
*         situated                                                    *
*                                                                     *
***********************************************************************
*                                                                     *
* OUTPUT:                                                             *
*                                                                     *
* dzdt    total differential in z direction [eta/time unit]           *
*                                                                     *
***********************************************************************
*
      include 'includepar'
      include 'includecom'

      integer indwz
      real wint,psint,zt,dzdt,sigma1,sigma2,zz1,zz2
      real dsigmadz,dsigmadz1,dsigmadz2,fract,geopot1,sigmatoh

      geopot1=sigmatoh(abs(sigmafull(1)),psint,ptop,p00,ts0,ta)

***********************************************************************
*                                                                     *
*     CALCULATION OF d(sigma)/dz: CENTERED DIFFERENCES SCHEME USED    *
*                                                                     *
***********************************************************************


***********************************************************************
*                                                                     *
*      CALCULATE d(sigma)/dz FOR LEVEL <indwz> (FIRST LEVEL)          *
*                                                                     *
***********************************************************************

      if(indwz.eq.1) then
        sigma1=sigmafull(1)
        sigma2=sigmafull(2)
        zz1=sigmatoh(abs(sigmafull(1)),psint,ptop,p00,ts0,ta)-
     &    geopot1
        zz2=sigmatoh(abs(sigmafull(2)),psint,ptop,p00,ts0,ta)-
     &    geopot1
      else
        sigma1=sigmafull(indwz-1)
        sigma2=sigmafull(indwz+1)
        zz1=sigmatoh(abs(sigmafull(indwz-1)),psint,ptop,p00,ts0,ta)-
     &    geopot1
        zz2=sigmatoh(abs(sigmafull(indwz+1)),psint,ptop,p00,ts0,ta)-
     &    geopot1
      endif
      dsigmadz1=(sigma2-sigma1)/(zz2-zz1)

***********************************************************************
*                                                                     *
*      CALCULATE d(sigma)/dz FOR LEVEL <indwz+1> (SECOND LEVEL)       *
*                                                                     *
***********************************************************************

      if(indwz+1.eq.nwz) then
        sigma1=sigmafull(nwz-1)
        sigma2=sigmafull(nwz)
        zz1=sigmatoh(abs(sigmafull(nwz-1)),psint,ptop,p00,ts0,ta)-
     &    geopot1
        zz2=sigmatoh(abs(sigmafull(nwz)),psint,ptop,p00,ts0,ta)-
     &    geopot1
      else
        sigma1=sigmafull(indwz)
        sigma2=sigmafull(indwz+2)
        zz1=sigmatoh(abs(sigmafull(indwz)),psint,ptop,p00,ts0,ta)-
     &    geopot1
        zz2=sigmatoh(abs(sigmafull(indwz+2)),psint,ptop,p00,ts0,ta)-
     &    geopot1
      endif
      dsigmadz2=(sigma2-sigma1)/(zz2-zz1)

***********************************************************************
*                                                                     *
*      LINEAR INTERPOLATION BETWEEN FIRST AND SECOND LEVEL            *
*                                                                     *
***********************************************************************

      fract=(zt-sigmafull(indwz))/(sigmafull(indwz+1)-sigmafull(indwz))
      dsigmadz=dsigmadz1*(1.-fract)+dsigmadz2*fract

***********************************************************************
*                                                                     *
*       TRANSFORMATION OF <wint> TO d(sigma)/dt                       *
*                                                                     *
***********************************************************************

      dzdt=wint*dsigmadz

      return
      end
