      subroutine xytolamphi(x,y,lam0,phi0,phitrue1,conef,
     &  lam,phi)

* THIS ROUTINE CALCULATES THE COORDINATES ON EARTH (LAMBDA/PHI) FROM
* THE COORDINATES ON THE PROJECTION PLANE
*
*                ********************************
*                * LAMBERT CONFORMAL PROJECTION *
*                ********************************
*
* INPUT:
*
* x            x position on projection plane (km relative to lam0/phi0)
* y            y position on projection plane (km relative to lam0/phi0)
* lam0         Projection center longitude
* phi0         Projection center latitude
* phitrue1     True latitude 1
* conef        Cone factor
*
* OUTPUT:
*
* lam          latitude
* phi          longitude
*
      implicit none

      real x,y,lam0,phi0,phitrue1,conef,lam,phi

      double precision radb,cpidb
      parameter(radb=6370.0d+3)   ! Earth radius
      double precision xdb,ydb,lam0db,phi0db
      double precision phitrue1db,conefdb,lamdb,phidb
      double precision cc1db,cc2db,psi0db,psi1db,help1db,rrdb,help2db
      double precision help3db,dsig

* CONVERT TO DOUBLE PRECISION
   
      xdb=dble(x)
      if(dabs(xdb).lt.1.d-3) xdb=+1.0d-3
      ydb=dble(y)
      lam0db=dble(lam0)
      phi0db=dble(phi0)
      phitrue1db=dble(phitrue1)
      conefdb=dble(conef)

      cpidb=4.0*datan(1.0d+0)/180.0d+0   ! Conversion factor to radian

* PERFORM COMPUTATIONS

      psi0db=dble(0.5)*cpidb*(dble(90.0)-phi0)
      psi1db=dble(0.5)*cpidb*phitrue1db

      cc2db=(radb/conefdb) * dsin (phitrue1db*cpidb) *
     & ((dtan(psi0db)/dtan(psi1db))**conefdb)
      cc1db=-lam0db-dble(90.0)/conefdb

      if(xdb.ge.0.d+0) then
        help1db=datan((ydb-cc2db)/xdb) / cpidb
      else
        help1db=dble(-90.0)-(90.0d+0-
     &    (datand((ydb-cc2db)/xdb)))
      endif
      lamdb=help1db/conefdb - cc1db

      if(dabs(dcos(help1db*cpidb)).gt.1.e-30) then
        rrdb=xdb/dcos(help1db*cpidb)
      else
        rrdb=(ydb-cc2db)/ dsin(help1db*cpidb)
      endif

      help3db=((conefdb*rrdb)/(radb*dsind(phitrue1db)))
     &   **(1.0d+0/conefdb)
      help3db=help3db*dtan(psi1db)
      help2db=dble(2.0)*datan(help3db) / cpidb
      phidb=dble(90.0)-help2db

* CONVERT RESULT BACK TO SINGLE PRECISION

      lam=sngl(lamdb)
      phi=sngl(phidb)

      return
      end
